@@ -28,4 +28,15 @@ class Application:
     async def fetch(self):
         response: ClientResponse = await self.client.api(self, "oauth2/applications/@me").request("GET")
         data: dict = await response.json()
-        self.application = Application(data)
\ No newline at end of file
+        self.application = Application(data)
+        
+class ApplicationCommand:
+    def __init__(self, data: dict):
+        self.id: str = data["id"]
+        self.type: int = data["type"]
+        self.application_id: str = data["application_id"]
+        self.guild_id: Optional[str] = data["guild_id"] or None
+        self.name: str = data["name"]
+        self.description: str = data["description"]
+        self.default_permissions: bool = data["default_permissions"]
+        self.version: str = data["version"]
\ No newline at end of file
